@@ -22,7 +22,8 @@ use std::fs::File;
 use std::io;
 use std::io::{Read, Write};
 use sys_locale::get_locale;
-use yozuk::{ModelSet, Yozuk};
+use yozuk::Yozuk;
+use yozuk_sdk::model::*;
 use yozuk_sdk::prelude::*;
 
 mod args;
@@ -73,9 +74,9 @@ impl App {
         };
 
         let zuk = Yozuk::builder()
-            .config(config)
-            .i18n(i18n)
-            .logger(logger)
+            .set_config(config)
+            .set_i18n(i18n)
+            .set_logger(logger)
             .build(ModelSet::from_data(yozuk_bundle::MODEL_DATA)?);
 
         Ok(Self { args, zuk })
